@@ -1,3 +1,4 @@
+from ._utils import get_app_data_from_toml, is_app_name
 from .parser import FalClientParser, RefAction
 
 
@@ -6,7 +7,17 @@ def _run(args):
     from fal.utils import load_function_from
 
     host = FalServerlessHost(args.host)
-    isolated_function, _ = load_function_from(host, *args.func_ref)
+
+    if is_app_name(args.func_ref):
+        app_name = args.func_ref[0]
+        app_ref, *_ = get_app_data_from_toml(app_name)
+        file_path, func_name = RefAction.split_ref(app_ref)
+    else:
+        file_path, func_name = args.func_ref
+
+    loaded = load_function_from(host, file_path, func_name)
+
+    isolated_function = loaded.function
     # let our exc handlers handle UserFunctionException
     isolated_function.reraise = False
     isolated_function()
@@ -14,10 +25,7 @@ def _run(args):
 
 def add_parser(main_subparsers, parents):
     run_help = "Run fal function."
-    epilog = (
-        "Examples:\n"
-        "  fal run path/to/myfile.py::myfunc"
-    )
+    epilog = "Examples:\n" "  fal run path/to/myfile.py::myfunc"
     parser = main_subparsers.add_parser(
         "run",
         description=run_help,
