@@ -1,11 +1,13 @@
 from __future__ import annotations
 
+import json
+from datetime import timedelta
 from typing import List
 
 from fal.sdk import RunnerInfo, RunnerState
 
 from ._utils import get_client
-from .parser import FalClientParser
+from .parser import FalClientParser, SinceAction, get_output_parser
 
 
 def runners_table(runners: List[RunnerInfo]):
@@ -14,8 +16,7 @@ def runners_table(runners: List[RunnerInfo]):
     table = Table()
     table.add_column("Alias")
     table.add_column("Runner ID")
-    table.add_column("In Flight Requests")
-    table.add_column("Missing Leases")
+    table.add_column("In Flight\nRequests")
     table.add_column("Expires In")
     table.add_column("Uptime")
     table.add_column("Revision")
@@ -33,18 +34,29 @@ def runners_table(runners: List[RunnerInfo]):
             ]
         )
 
+        in_flight = str(runner.in_flight_requests)
+        missing_leases = runner.in_flight_requests - num_leases_with_request
+        if missing_leases > 0:
+            # Show a small indicator of in flight requests that are not visible in the
+            # leases lists
+            # This can be due to race conditions, so only important to report if it's
+            # consistent
+            in_flight = f"{in_flight} [dim]({missing_leases})[/]"
+
+        uptime = timedelta(
+            seconds=int(runner.uptime.total_seconds()),
+        )
         table.add_row(
             runner.alias,
             # Mark lost runners in red
             runner.runner_id if present else f"[red]{runner.runner_id}[/]",
-            str(runner.in_flight_requests),
-            str(runner.in_flight_requests - num_leases_with_request),
+            in_flight,
             (
-                "N/A (active)"
+                "N/A"
                 if runner.expiration_countdown is None
                 else f"{runner.expiration_countdown}s"
             ),
-            f"{runner.uptime} ({runner.uptime.total_seconds()}s)",
+            f"{uptime} ({uptime.total_seconds():.0f}s)",
             runner.revision,
             runner.state.value,
         )
@@ -80,20 +92,66 @@ def _kill(args):
         connection.kill_runner(args.id)
 
 
+def _list_json(args, runners: list[RunnerInfo]):
+    json_runners = [
+        {
+            "alias": r.alias,
+            "runner_id": r.runner_id,
+            "in_flight_requests": r.in_flight_requests,
+            "expiration_countdown": r.expiration_countdown,
+            "uptime_seconds": int(r.uptime.total_seconds()),
+            "revision": r.revision,
+            "state": r.state.value,
+        }
+        for r in runners
+    ]
+
+    res = {
+        "runners": json_runners,
+    }
+    args.console.print(json.dumps(res))
+
+
 def _list(args):
     client = get_client(args.host, args.team)
     with client.connect() as connection:
-        runners = connection.list_runners()
+        start_time = getattr(args, "since", None)
+        runners = connection.list_runners(start_time=start_time)
+
+        if getattr(args, "state", None):
+            states = set(args.state)
+            if "all" not in states:
+                runners = [r for r in runners if r.state.value in states]
         pending_runners = [
             runner for runner in runners if runner.state == RunnerState.PENDING
         ]
-        args.console.print(f"Runners: {len(runners) - len(pending_runners)}")
-        args.console.print(f"Pending Runners: {len(pending_runners)}")
-        args.console.print(runners_table(runners))
+        setup_runners = [
+            runner for runner in runners if runner.state == RunnerState.SETUP
+        ]
+        dead_runners = [
+            runner for runner in runners if runner.state == RunnerState.DEAD
+        ]
+        if args.output == "pretty":
+            args.console.print(
+                "Runners: "
+                + str(
+                    len(runners)
+                    - len(pending_runners)
+                    - len(setup_runners)
+                    - len(dead_runners)
+                )
+            )
+            args.console.print(f"Runners Pending: {len(pending_runners)}")
+            args.console.print(f"Runners Setting Up: {len(setup_runners)}")
+            args.console.print(runners_table(runners))
 
-        requests_table = runners_requests_table(runners)
-        args.console.print(f"Requests: {len(requests_table.rows)}")
-        args.console.print(requests_table)
+            requests_table = runners_requests_table(runners)
+            args.console.print(f"Requests: {len(requests_table.rows)}")
+            args.console.print(requests_table)
+        elif args.output == "json":
+            _list_json(args, runners)
+        else:
+            raise AssertionError(f"Invalid output format: {args.output}")
 
 
 def _add_kill_parser(subparsers, parents):
@@ -117,7 +175,25 @@ def _add_list_parser(subparsers, parents):
         "list",
         description=list_help,
         help=list_help,
-        parents=parents,
+        parents=[*parents, get_output_parser()],
+    )
+    parser.add_argument(
+        "--since",
+        default=None,
+        action=SinceAction,
+        limit="1 day",
+        help=(
+            "Show dead runners since the given time. "
+            "Accepts 'now', relative like '30m', '1h', '1d', "
+            "or an ISO timestamp. Max 24 hours."
+        ),
+    )
+    parser.add_argument(
+        "--state",
+        choices=["all", "running", "pending", "setup", "dead"],
+        nargs="+",
+        default=None,
+        help=("Filter by runner state(s). Choose one or more, or 'all'(default)."),
     )
     parser.set_defaults(func=_list)
 
