@@ -8,3 +8,9 @@ class FileUploadException(FalTookitException):
     """Raised when file upload fails"""
 
     pass
+
+
+class KVStoreException(FalTookitException):
+    """Raised when KV store operation fails"""
+
+    pass
